Page 35 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 35

Home

    We must acquire the direction of education — of
    church-management — of the professional chair, and of
    the pulpit. We must bring our opinions into fashion by
    every art...

    To insure secrecy in their private correspondence,
    leaders of the Order took ancient names. Weishaupt was

    Spartacus, Zwack (a judge) was Cato, and so on.
    Members were advised to practice writing with both
    hands to further obscure their identity. The secrets of the

    Order were so well guarded that no one outside of a
    small circle knew that Weishaupt was the head of the
    Order until its papers were seized in 1786.

    Their attitude toward religion was to profess

    Their

    toward

    Their attitude toward religion was to profess
    Christianity while working to destroy it. They taught
    that, rather than God creating the universe, the universe
    is creating God and that man is himself god and therefore
    unaccountable to a higher power. This is similar to the
    New Age doctrine of the 20th century.

    They also taught that Jesus had a secret doctrine, a
    doctrine of reason that only the enlightened could
    understand. Rather than being a redeemer, Jesus was

    profess

    to

    was

    only a teacher whose purpose was to unite men in a great
    universal association thereby leading men to universal

    30

    The Secret Side of History

    other avenue that served to mold public opinion. Then-

    stated objectives were:

    liberty and equality.